package Bundle::CPANPLUS::Dependencies;

$VERSION = "0.02";

1;

__END__

=head1 NAME

Bundle::CPANPLUS::Dependencies -- All modules required & desired by CPANPLUS

=head1 SYNOPSIS

    perl -MCPANPLUS -e 'install Bundle::CPANPLUS::Dependencies'

    perl -MCPAN -e 'install Bundle::CPANPLUS::Dependencies'

=head1 DESCRIPTION

Bundle to install all modules required & desired by CPANPLUS 

=head1 CONTENTS

Archive::Extract 0.07

Archive::Tar 1.23

Archive::Zip

Bundle::CPANPLUS::Test::Reporter

Compress::Zlib

Digest::MD5

File::Fetch 0.07

IO::Zlib 1.04

IPC::Cmd 0.24

IPC::Run 0.77

Locale::Maketext::Simple

Log::Message

LWP

LWP::UserAgent

Module::Build 0.2607

Module::CoreList 1.97

Module::Load 0.10

Module::Load::Conditional 0.07

Module::Pluggable 2.4

Module::Signature 0.44

Net::FTP

Object::Accessor 0.03

Params::Check 0.22

Storable

Term::ReadLine::Perl

Term::UI 0.05

Test::More

URI

YAML

=head1 AUTHOR

Jos Boumans <kane@cpan.org>

=cut 


__END__
